@@ -2,12 +2,13 @@ const assert = require('assert')
 const child = require('child_process')
 const fs = require('fs')
 const path = require('path')
-const tap = require('tap')
 const pkg = require('../package.json')
 
 const cliPath = path.resolve(__dirname, '../lib/cli.js')
 
-tap.test('CLI', t => {
+const t = require('tap')
+
+t.test('CLI', t => {
     t.test('converts JSON5 to JSON from stdin to stdout', t => {
         const proc = child.spawn(process.execPath, [cliPath])
         let output = ''
